Functions
:::::::::

.. toctree::
   :caption: Functions
   :maxdepth: 2

   functions.rst
   Functionsthatreturnvalues.rst
   UnitTesting.rst
   Variablesandparametersarelocal.rst
   TheAccumulatorPattern.rst
   Functionscancallotherfunctions.rst
   FlowofExecutionSummary.rst
   mainfunction.rst
   ProgramDevelopment.rst
   Composition.rst
   ATurtleBarChart.rst
   Glossary.rst
   Exercises.rst
